Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(90)

Unified Diff: ash/shelf/shelf_widget.h

Issue 115113006: Rename Launcher to Shelf. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: ShelfTestAPI Created 7 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ash/shelf/shelf_widget.h
diff --git a/ash/shelf/shelf_widget.h b/ash/shelf/shelf_widget.h
index 83d4a8d70135a1bc30c8c8ecd7f2eb9d09ed5f8c..967bf357b4a1ad9be5c4f3b21b0ecba259e39119 100644
--- a/ash/shelf/shelf_widget.h
+++ b/ash/shelf/shelf_widget.h
@@ -16,7 +16,7 @@ class Window;
}
namespace ash {
-class Launcher;
+class Shelf;
namespace internal {
class FocusCycler;
@@ -54,22 +54,22 @@ class ASH_EXPORT ShelfWidget : public views::Widget,
internal::ShelfLayoutManager* shelf_layout_manager() {
return shelf_layout_manager_;
}
- Launcher* launcher() const { return launcher_.get(); }
+ Shelf* shelf() const { return shelf_.get(); }
internal::StatusAreaWidget* status_area_widget() const {
return status_area_widget_;
}
- void CreateLauncher();
+ void CreateShelf();
- // Set visibility of the launcher component of the shelf.
- void SetLauncherVisibility(bool visible);
- bool IsLauncherVisible() const;
+ // Set visibility of the shelf.
+ void SetShelfVisibility(bool visible);
+ bool IsShelfVisible() const;
- // Sets the focus cycler. Also adds the launcher to the cycle.
+ // Sets the focus cycler. Also adds the shelf to the cycle.
void SetFocusCycler(internal::FocusCycler* focus_cycler);
internal::FocusCycler* GetFocusCycler();
// Called by the activation delegate, before the launcher is activated
// when no other windows are visible.
void WillActivateAsFallback() { activating_as_fallback_ = true; }
@@ -100,7 +100,7 @@ class ASH_EXPORT ShelfWidget : public views::Widget,
class DelegateView;
internal::ShelfLayoutManager* shelf_layout_manager_;
- scoped_ptr<Launcher> launcher_;
+ scoped_ptr<Shelf> shelf_;
internal::StatusAreaWidget* status_area_widget_;
// delegate_view_ is attached to window_container_ and is cleaned up
@@ -54,22 +54,22 @@ class ASH_EXPORT ShelfWidget : public views::Widget,
void SetFocusCycler(internal::FocusCycler* focus_cycler);
internal::FocusCycler* GetFocusCycler();
- // Called by the activation delegate, before the launcher is activated
+ // Called by the activation delegate, before the shelf is activated
// when no other windows are visible.
void WillActivateAsFallback() { activating_as_fallback_ = true; }

Powered by Google App Engine
This is Rietveld 408576698